Contributing
============

Bug reports, feature requests, and other contributions are welcome.
If you find a demonstrable problem that is caused by the code of this
library, please:

1. Search for `already reported problems
   <https://github.com/inveniosoftware/flask-sitemap/issues>`_.
2. Check if the issue has been fixed or is still reproducible on the
   latest `master` branch.
3. Create an issue with **a test case**.

If you create a feature branch, you can run the tests to ensure everything is
operating correctly:

.. code-block:: console

    $ ./run-tests.sh
    ...
    Ran 8 tests in 0.246s

    OK
    Name                 Stmts   Miss  Cover   Missing
    --------------------------------------------------
    flask_sitemap/__init__      47      0   100%
    flask_sitemap/config         4      0   100%
    flask_sitemap/version        2      0   100%
    --------------------------------------------------
    TOTAL                   53      0   100%
